/*
 * Copyright 2003-2006 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.log4j.test; 

import org.apache.log4j.*;
import org.apache.log4j.helpers.LogLog;

/**
   Very simple log4j usage example.

   @author  Ceki G&uuml;lc&uuml;  
   @author <a href="mailto:ralph.curtis@gabrielsoftware.com">Ralph Curtis</a> 
 */
public class Hello {

  static Logger log = Logger.getInstance(Hello.class);
  /* Example of using two different loggers in same class. */
  static Logger consoleLogger = Logger.getInstance(Hello.class.getName()+" ConsoleLogger");

  public 
  static 
  void main(String argv[]) {
    Logger root = Logger.getRoot();
    Layout layout = new PatternLayout("%D %p [%t] %c - %m%n");
    try {
//      root.addAppender(new FileAppender(layout, System.out));
      root.addAppender(new ConsoleAppender(layout));
//        root.addAppender(new FileAppender(layout, "testlog.log"));
        log.addAppender(new FileAppender(layout, "testlog.log"));
      consoleLogger.addAppender(new ConsoleAppender());
    } catch(Exception e) {
      LogLog.warn("Could not open file appender.");
    }

    log.debug("Hello world.");
    log.info("What a beatiful day.");
    int max = 100000;
    consoleLogger.info("Writing "+max +" logs");
    long t1;
    long t0 = System.currentTimeMillis();
    for(int i = 0; i < max; ++i) {
    	log.info("What a beautiful day.");
    }
    t1 = System.currentTimeMillis();
    consoleLogger.info("Test done. Logged: " +max +" logs in " +(t1-t0) +" msec");
  }
}
