/*
 * Copyright 2003-2006 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.log4j.test; 

import org.apache.log4j.*;
import org.apache.log4j.helpers.LogLog;
import java.io.IOException;
import java.util.Enumeration;
/** 
   This class is a shallow test of the various appenders and
   layouts. It also tests their reading of the configuration file.
   @author  Ceki G&uuml;lc&uuml;
*/
public class Shallow {
  
  static Logger cat = Logger.getInstance(Shallow.class);
  
  public 
  static 
  void main(String argv[]) {
    if(argv.length == 2) 
      init(argv[0], argv[1]);
    else 
      usage("Wrong number of arguments.");
    test();
  }

  static
  void usage(String msg) {
    System.err.println(msg);
    System.err.println( "Usage: java "+ Shallow.class.getName()+" file format");
    System.exit(1);
  }

  static 
  void init(String file, String format) {
    Logger root = Logger.getRoot();
    Layout layout = new PatternLayout(format);
    try {
      root.addAppender(new FileAppender(layout, file));
    } catch(Exception e) {
      LogLog.warn("Could not open file ["+file+"].");
    }
  }

  static 
  void test() {
    int i = -1; 

    Logger root = Logger.getRoot();
    cat.debug("Message " + ++i);
    root.debug("Message " + i);
    cat.info ("Message " + ++i);
    cat.warn ("Message " + ++i);
    cat.error("Message " + ++i);
    
    Exception e = new Exception("Just testing");
    cat.debug("Message " + ++i, e);    
    root.info("Message " + ++i, e);
    cat.warn("Message " + ++i, e);
    root.error("Message " + ++i, e);
  }
}
